@@ -17,11 +17,11 @@ WebService::Careerjet - Perl interface to Careerjet's public job offers search A
 
 =head1 VERSION
 
-Version 3.0
+Version 3.1
 
 =cut
 
-our $VERSION = '3.0';
+our $VERSION = '3.1';
 
 =head1 SYNOPSIS
 
@@ -109,7 +109,7 @@ Available locales:
     en_AU      English          Australia            http://www.careerjet.com.au
     en_BD      English          Bangladesh           http://www.careerjet.com.bd
     en_CA      English          Canada               http://www.careerjet.ca
-    en_CN      English          China                http://en.careerjet.cn
+    en_CN      English          China                http://www.career-jet.cn
     en_HK      English          Hong Kong            http://www.careerjet.hk
     en_IE      English          Ireland              http://www.careerjet.ie
     en_IN      English          India                http://www.careerjet.co.in
@@ -144,7 +144,7 @@ Available locales:
     es_UY      Spanish          Uruguay              http://www.opcionempleo.com.uy
     es_VE      Spanish          Venezuela            http://www.opcionempleo.com.ve
     fi_FI      Finnish          Finland              http://www.careerjet.fi
-    fr_CA      French           Canada               http://fr.careerjet.ca
+    fr_CA      French           Canada               http://www.option-carriere.ca
     fr_BE      French           Belgium              http://www.optioncarriere.be
     fr_CH      French           Switzerland          http://www.optioncarriere.ch
     fr_FR      French           France               http://www.optioncarriere.com
